==> apache-streampipes-0.90.0-source-release.zip: apache-streampipes-0.90.0/streampipes-pipeline-management/src/main/java/org/apache/streampipes/manager/matching/output/UserDefinedOutputSchemaGenerator.java <==
package org.apache.streampipes.manager.matching.output;/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import org.apache.streampipes.model.SpDataStream;
import org.apache.streampipes.model.output.OutputStrategy;
import org.apache.streampipes.model.output.UserDefinedOutputStrategy;
import org.apache.streampipes.model.schema.EventProperty;
import org.apache.streampipes.model.schema.EventSchema;
import org.apache.streampipes.sdk.helpers.Tuple2;

import java.util.List;

public class UserDefinedOutputSchemaGenerator extends OutputSchemaGenerator<UserDefinedOutputStrategy> {

  private List<EventProperty> producedProperties;

  public static UserDefinedOutputSchemaGenerator from(OutputStrategy strategy) {
    return new UserDefinedOutputSchemaGenerator((UserDefinedOutputStrategy) strategy);
  }

  public UserDefinedOutputSchemaGenerator(UserDefinedOutputStrategy strategy) {
    super(strategy);
    this.producedProperties = strategy.getEventProperties();
  }

  @Override
  public Tuple2<EventSchema, UserDefinedOutputStrategy> buildFromOneStream(SpDataStream stream) {
    return makeTuple(new EventSchema(producedProperties));
  }

  @Override
  public Tuple2<EventSchema, UserDefinedOutputStrategy> buildFromTwoStreams(SpDataStream stream1, SpDataStream stream2) {
    return buildFromOneStream(stream1);
  }
}

==> apache-streampipes-0.98.0-source-release.zip: apache-streampipes-0.98.0/streampipes-pipeline-management/src/main/java/org/apache/streampipes/manager/matching/output/UserDefinedOutputSchemaGenerator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.manager.matching.output;

import org.apache.streampipes.model.SpDataStream;
import org.apache.streampipes.model.output.OutputStrategy;
import org.apache.streampipes.model.output.UserDefinedOutputStrategy;
import org.apache.streampipes.model.schema.EventProperty;
import org.apache.streampipes.model.schema.EventSchema;
import org.apache.streampipes.sdk.helpers.Tuple2;

import java.util.List;

public class UserDefinedOutputSchemaGenerator extends OutputSchemaGenerator<UserDefinedOutputStrategy> {

  private List<EventProperty> producedProperties;

  public static UserDefinedOutputSchemaGenerator from(OutputStrategy strategy) {
    return new UserDefinedOutputSchemaGenerator((UserDefinedOutputStrategy) strategy);
  }

  public UserDefinedOutputSchemaGenerator(UserDefinedOutputStrategy strategy) {
    super(strategy);
    this.producedProperties = strategy.getEventProperties();
  }

  @Override
  public Tuple2<EventSchema, UserDefinedOutputStrategy> buildFromOneStream(SpDataStream stream) {
    return makeTuple(new EventSchema(producedProperties));
  }

  @Override
  public Tuple2<EventSchema, UserDefinedOutputStrategy> buildFromTwoStreams(SpDataStream stream1,
                                                                            SpDataStream stream2) {
    return buildFromOneStream(stream1);
  }
}
